| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
SMTLIB.Backends.Process
Description
A module providing a backend that launches solvers as external processes.
Documentation
Constructors
| Config | |
Fields
| |
Run a solver as a process. Failures relative to terminating the process are logged and discarded.
close :: Handle -> IO () Source #
Terminate the process, wait for it to actually exit and cleanup its resources.
Don't use this if you're manually stopping the solver process by sending an
(exit) command. Use wait instead.